@@ -13,7 +13,6 @@
 #' \donttest{
 #' interactive_implode(wizard)
 #' }
-
 interactive_implode <- function(image, range_max = 1, resolution = 0.1, return_param = FALSE)
 {
   # make initial output
@@ -23,7 +22,7 @@ interactive_implode <- function(image, range_max = 1, resolution = 0.1, return_p
   # set variable range
   iminfo <- image_info(image)
   range_radius <- c(0,range_max)
-  length_slider <- as.integer(iminfo["width"] * 0.6) # length of slider
+  length_slider <- as.integer(iminfo$width * 0.6) # length of slider
   if (length_slider < 200)
   {
     length_slider <- 200
